@@ -4,7 +4,7 @@ import sqlalchemy.types as types
 from sqlalchemy.dialects.postgresql.base import ischema_names
 
 
-class CIText(types.UserDefinedType):
+class CIText(types.Concatenable, types.UserDefinedType):
 
     def get_col_spec(self):
         return 'CITEXT'
